Gentelella Alela! |

Welcome,

## John Doe

### Pricing Tables

## Pricing Tables Design

## Tally Box Design

# free

- 2 years access to all storage locations
- Unlimited storage
- Limited download quota
- Cash on Delivery
- All time updates
- Unlimited access to all files
- Allowed to be exclusing per sale

30% Off

## Tally Box Design

# $25

Monthly

- 2 years access to all storage locations
- Unlimited storage
- Limited download quota
- Cash on Delivery
- All time updates
- Unlimited access to all files
- Allowed to be exclusing per sale

## Tally Box Design

# $25

Monthly

- 2 years access to all storage locations
- Unlimited storage
- Limited download quota
- Cash on Delivery
- All time updates
- Unlimited access to all files
- Allowed to be exclusing per sale

## Tally Box Design

# $25

Monthly

- 2 years access to all storage locations
- Unlimited storage
- Limited download quota
- Cash on Delivery
- All time updates
- Unlimited access to all files
- Allowed to be exclusing per sale